@@ -923,15 +923,23 @@ class EnforcerTest(base.PolicyBaseTestCase):
         target_dict = {}
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, do_raise=True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
         # model a project-scoped token, which should fail enforcement
         ctx = context.RequestContext(project_id='fake')
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
     def test_enforcer_understands_domain_scope(self):
         self.conf.set_override('enforce_scope', True, group='oslo_policy')
@@ -956,15 +964,23 @@ class EnforcerTest(base.PolicyBaseTestCase):
         target_dict = {}
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
         # model a project-scoped token, which should fail enforcement
         ctx = context.RequestContext(project_id='fake')
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
     def test_enforcer_understands_project_scope(self):
         self.conf.set_override('enforce_scope', True, group='oslo_policy')
@@ -989,15 +1005,23 @@ class EnforcerTest(base.PolicyBaseTestCase):
         target_dict = {}
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
         # model a domain-scoped token, which should fail enforcement
         ctx = context.RequestContext(domain_id='fake')
         self.assertRaises(
             policy.InvalidScope, self.enforcer.enforce, 'fake_rule',
-            target_dict, ctx
+            target_dict, ctx, True
         )
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(
+                'fake_rule', target_dict, ctx, do_raise=False))
 
     def test_enforce_scope_with_subclassed_checks_when_scope_not_set(self):
         self.conf.set_override('enforce_scope', True, group='oslo_policy')
@@ -1013,7 +1037,10 @@ class EnforcerTest(base.PolicyBaseTestCase):
         ctx = context.RequestContext(system_scope='all', roles=['admin'])
         self.assertRaises(
             policy.InvalidScope,
-            self.enforcer.enforce, rule, {}, ctx)
+            self.enforcer.enforce, rule, {}, ctx, do_raise=True)
+        # and the same should return False if do_raise=False
+        self.assertFalse(
+            self.enforcer.enforce(rule, {}, ctx, do_raise=False))
 
 
 class EnforcerNoPolicyFileTest(base.PolicyBaseTestCase):
@@ -1921,6 +1948,18 @@ class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
         self.assertFalse(self.enforcer.check_rules())
         mock_log.warning.assert_called()
 
+    @mock.patch.object(policy, 'LOG')
+    def test_undefined_rule_skipped(self, mock_log):
+        rules = jsonutils.dumps({'foo': 'rule:bar'})
+        self.create_config_file('policy.json', rules)
+        self.enforcer.skip_undefined_check = True
+        self.enforcer.load_rules(True)
+
+        self.assertTrue(self.enforcer.check_rules())
+        # TODO(tkajinam): This fails because of warnings caused by JSON format
+        # policy file used
+        # mock_log.warning.assert_not_called()
+
     @mock.patch.object(policy, 'LOG')
     def test_undefined_rule_raises(self, mock_log):
         rules = jsonutils.dumps({'foo': 'rule:bar'})
@@ -1931,6 +1970,18 @@ class EnforcerCheckRulesTest(base.PolicyBaseTestCase):
                           self.enforcer.check_rules, raise_on_violation=True)
         mock_log.warning.assert_called()
 
+    @mock.patch.object(policy, 'LOG')
+    def test_undefined_rule_raises_skipped(self, mock_log):
+        rules = jsonutils.dumps({'foo': 'rule:bar'})
+        self.create_config_file('policy.json', rules)
+        self.enforcer.skip_undefined_check = True
+        self.enforcer.load_rules(True)
+
+        self.assertTrue(self.enforcer.check_rules(raise_on_violation=True))
+        # TODO(tkajinam): This fails because of warnings caused by JSON format
+        # policy file used
+        # mock_log.warning.assert_not_called()
+
     @mock.patch.object(policy, 'LOG')
     def test_cyclical_rules(self, mock_log):
         rules = jsonutils.dumps({'foo': 'rule:bar', 'bar': 'rule:foo'})
